use anyhow::Result;

use std::str::from_utf8;

use super::validator::str_into;

#[derive(Default, Debug)]
pub struct RootInfo {
    pub reference_width: Option<u32>,
    pub reference_height: Option<u32>,
    pub ui_layer: Option<i32>,
}

impl RootInfo {
    pub fn new<'a>(attributes: quick_xml::events::attributes::Attributes<'a>) -> Result<Self> {
        let mut root_info = RootInfo::default();

        for attribute_res in attributes {
            let attribute = attribute_res?;

            match attribute.key.into_inner() {
                b"reference_width" => root_info.reference_width = Some(str_into(attribute.value)?),
                b"reference_height" => {
                    root_info.reference_height = Some(str_into(attribute.value)?)
                }
                b"layer" => root_info.ui_layer = Some(str_into(attribute.value)?),
                _ => {
                    return Err(anyhow::Error::msg(format!(
                        "Unsupported attribute in Root: {}",
                        from_utf8(attribute.key.into_inner())?
                    )))
                }
            }
        }

        Ok(root_info)
    }
}
